@@ -333,18 +333,20 @@ class account():
                  receive_count = receive_count + 1
 
             if (receive_count > 0):
-                #note = osso.SystemNote(self.osso_c)
-                #result = note.system_note_infoprint(str(receive_count) + " Mentions Received")
-                n = pynotify.Notification("Witter","You have "+str(receive_count)+" new mentions")
-                n.set_urgency(pynotify.URGENCY_CRITICAL)
-                icon= gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
-                #n.add_action("clicked","Show DMs", self.dm_callback)
-                n.set_hint("dbus-callback-default", "uk.wouldd.witter /uk/wouldd/witter uk.wouldd.witter open_mentions")
-                n.set_icon_from_pixbuf(icon)
-                rpc = osso.Rpc(self.osso_c)
-                rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._ENABLE_LED,rpc_args=(self._LED_PATTERN,"",""),use_system_bus=True)
-                rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._VIBRATE,rpc_args=(self._VIBRATE_PATTERN,"",""),use_system_bus=True)
-                #n.attach_to_widget(self.controller.ui.window)
+                if (self.controller.emailnotifications == False):
+                    note = osso.SystemNote(self.osso_c)
+                    result = note.system_note_infoprint(str(receive_count) + " Mentions Received")
+                else:
+                    n = pynotify.Notification("Witter","You have "+str(receive_count)+" new mentions")
+                    n.set_urgency(pynotify.URGENCY_CRITICAL)
+                    icon= gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
+                    #n.add_action("clicked","Show DMs", self.dm_callback)
+                    n.set_hint("dbus-callback-default", "uk.wouldd.witter /uk/wouldd/witter uk.wouldd.witter open_mentions")
+                    n.set_icon_from_pixbuf(icon)
+                    rpc = osso.Rpc(self.osso_c)
+                    rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._ENABLE_LED,rpc_args=(self._LED_PATTERN,"",""),use_system_bus=True)
+                    rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._VIBRATE,rpc_args=(self._VIBRATE_PATTERN,"",""),use_system_bus=True)
+                    #n.attach_to_widget(self.controller.ui.window)
                 
                 n.show()
 
@@ -418,17 +420,19 @@ class account():
                  receive_count = receive_count + 1
 
             if (receive_count > 0):
-                #note = osso.SystemNote(self.osso_c)
-                #result = note.system_note_infoprint(str(receive_count) + " DMs Received")
-                n = pynotify.Notification("Witter","You have "+str(receive_count)+" new DMs")
-                icon= gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
-                n.set_icon_from_pixbuf(icon)                
-                n.set_urgency(pynotify.URGENCY_CRITICAL)
-                n.set_hint("dbus-callback-default", "uk.wouldd.witter /uk/wouldd/witter uk.wouldd.witter open_dm")
-                rpc = osso.Rpc(self.osso_c)
-                rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._ENABLE_LED,rpc_args=(self._LED_PATTERN,"",""),use_system_bus=True)
-                rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._VIBRATE,rpc_args=(self._VIBRATE_PATTERN,"",""),use_system_bus=True)
-                #dmnotify.add_action("clicked","Show DMs", self.dm_callback)
+                if (self.controller.emailnotifications == False):
+                    note = osso.SystemNote(self.osso_c)
+                    result = note.system_note_infoprint(str(receive_count) + " DMs Received")
+                else:
+                    n = pynotify.Notification("Witter","You have "+str(receive_count)+" new DMs")
+                    icon= gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
+                    n.set_icon_from_pixbuf(icon)                
+                    n.set_urgency(pynotify.URGENCY_CRITICAL)
+                    n.set_hint("dbus-callback-default", "uk.wouldd.witter /uk/wouldd/witter uk.wouldd.witter open_dm")
+                    rpc = osso.Rpc(self.osso_c)
+                    rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._ENABLE_LED,rpc_args=(self._LED_PATTERN,"",""),use_system_bus=True)
+                    rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._VIBRATE,rpc_args=(self._VIBRATE_PATTERN,"",""),use_system_bus=True)
+                    #dmnotify.add_action("clicked","Show DMs", self.dm_callback)
 
                 #n.attach_to_widget(self.controller.ui.window)
                 n.show()
